@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -224,7 +196,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
                     if (SHUTDOWN_REQUESTED.get()) {
                         // 503 - Service Unavailable
                         try {
-                            setStatusAndWriteErrorPage(shutDownStatus, null, request, response);
+                            setStatusAndWriteErrorPage(shutDownStatus, null, response);
                         } catch (Exception e) {
                             LOG.warn("Failed to commit 503 status.", e);
                         }
@@ -272,7 +244,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
             if (SHUTDOWN_REQUESTED.get()) {
                 // 503 - Service Unavailable
                 try {
-                    setStatusAndWriteErrorPage(shutDownStatus, null, request, response);
+                    setStatusAndWriteErrorPage(shutDownStatus, null, response);
                 } catch (Exception e) {
                     LOG.warn("Failed to commit 503 status.", e);
                 }
@@ -311,7 +283,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
                     LOG.error(logBuilder.toString(), t);
                     // 500 - Internal Server Error
                     try {
-                        setStatusAndWriteErrorPage(HttpStatus.INTERNAL_SERVER_ERROR_500, null, request, response);
+                        setStatusAndWriteErrorPage(HttpStatus.INTERNAL_SERVER_ERROR_500, null, response);
                     } catch (Exception e) {
                         LOG.warn("Failed to commit 500 status.", e);
                     }
@@ -324,7 +296,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
 
         if (!invoked) {
             try {
-                setStatusAndWriteErrorPage(HttpStatus.NOT_FOUND_404, "Resource does not exist.", request, response);
+                setStatusAndWriteErrorPage(HttpStatus.NOT_FOUND_404, "Resource does not exist.", response);
             } catch (Exception e) {
                 LOG.warn("Failed to commit 404 status.", e);
             }
@@ -361,7 +333,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
      */
     public void registerServletHandler(final String alias,
                                        final Servlet servlet,
-                                       final Dictionary initparams,
+                                       final Dictionary<?, ?> initparams,
                                        HttpContext context,
                                        final HttpService httpService)
             throws NamespaceException, ServletException {
@@ -466,7 +438,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
      */
     public void registerFilter(final Filter filter,
                                final String urlPattern,
-                               final Dictionary initparams,
+                               final Dictionary<?, ?> initparams,
                                HttpContext context,
                                final HttpService httpService)
             throws ServletException {
@@ -675,23 +647,6 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
         }
     }
 
-    /**
-     * Check if <code>servlet</code> has been already registered.
-     * <p/>
-     * An instance of {@link Servlet} can be registered only once, so in case of servlet been registered before will throw
-     * {@link ServletException} as specified in OSGi HttpService Spec.
-     *
-     * @param servlet {@link Servlet} to check if can be registered.
-     * @throws ServletException Iff <code>servlet</code> has been registered before.
-     */
-    private void validateServlet4RegOk(Servlet servlet) throws ServletException {
-        if (OSGiCleanMapper.containsServlet(servlet)) {
-            String msg = "Servlet: '" + servlet + "', already registered.";
-            LOG.warn(msg);
-            throw new ServletException(msg);
-        }
-    }
-
     /**
      * Looks up {@link OSGiServletHandler}.
      * <p/>
@@ -705,7 +660,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
      * @return Found or created {@link OSGiServletHandler}.
      */
     private OSGiServletHandler findOrCreateOSGiServletHandler(
-            Servlet servlet, HttpContext httpContext, Dictionary initparams) {
+            Servlet servlet, HttpContext httpContext, Dictionary<?, ?> initparams) {
         OSGiServletHandler osgiServletHandler;
 
         List<OSGiServletHandler> servletHandlers =
@@ -783,7 +738,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
         return errorPageGenerator;
     }
 
-    private void setStatusAndWriteErrorPage(HttpStatus status, String optDescription, Request req, Response res) throws Exception {
+    private void setStatusAndWriteErrorPage(HttpStatus status, String optDescription, Response res) throws Exception {
         res.setStatus(status);
         final ByteBuffer bb = getErrorPage(status.getStatusCode(), status.getReasonPhrase(), null == optDescription ? status.getReasonPhrase() : optDescription);
         res.setContentLength(bb.limit());
