@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH. group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -153,7 +125,6 @@ public class OXHttpServerFilter extends HttpServerFilter {
     }
 
     @Override
-    @SuppressWarnings({"UnusedDeclaration"})
     public HttpHandler getHttpHandler() {
         return httpHandler;
     }
@@ -165,7 +136,6 @@ public class OXHttpServerFilter extends HttpServerFilter {
 
     // ----------------------------------------------------- Methods from Filter
 
-    @SuppressWarnings({"unchecked", "ReturnInsideFinallyBlock"})
     @Override
     public NextAction handleRead(final FilterChainContext ctx)
           throws IOException {
@@ -175,130 +145,127 @@ public class OXHttpServerFilter extends HttpServerFilter {
         assert HttpContext.get(ctx) != null;
 
         final Object message = ctx.getMessage();
-        final Connection connection = ctx.getConnection();
+        final Connection<?> connection = ctx.getConnection();
 
-        if (HttpPacket.isHttp(message)) {
-            // Otherwise cast message to a HttpContent
-            final HttpContent httpContent = (HttpContent) message;
-            final HttpContext context = httpContent.getHttpHeader()
-                    .getProcessingState().getHttpContext();
-            Request handlerRequest = httpRequestInProgress.get(context);
-
-            if (handlerRequest == null) {
-                // It's a new HTTP request
-                final HttpRequestPacket request = (HttpRequestPacket) httpContent.getHttpHeader();
-                final HttpResponsePacket response = request.getResponse();
-                ServerFilterConfiguration config = getConfiguration();
-
-                handlerRequest = OXRequest.create(grizzlyConfig);
-                handlerRequest.parameters.setLimit(config.getMaxRequestParameters());
-                httpRequestInProgress.set(context, handlerRequest);
-                final Response handlerResponse = handlerRequest.getResponse();
-
-                handlerRequest.initialize(request, ctx, this);
-                handlerResponse.initialize(handlerRequest, response,
-                        ctx, suspendedResponseQueue, this);
-
-                if (config.isGracefulShutdownSupported()) {
-                    activeRequestsCounter.incrementAndGet();
-                    handlerRequest.addAfterServiceListener(flushResponseHandler);
-                }
-
-                HttpServerProbeNotifier.notifyRequestReceive(this, connection,
-                        handlerRequest);
-
-                boolean wasSuspended = false;
-
-                try {
-                    ctx.setMessage(handlerResponse);
-
-                    if (shuttingDown.get()) { // if we're in the shutting down phase - serve shutdown page and exit
-                        handlerResponse.getResponse().getProcessingState().setError(true);
-                        HtmlHelper.setErrorAndSendErrorPage(
-                                handlerRequest, handlerResponse,
-                                config.getDefaultErrorPageGenerator(),
-                                503, HttpStatus.SERVICE_UNAVAILABLE_503.getReasonPhrase(),
-                                "The server is being shutting down...", null);
-                    } else if (!config.isPassTraceRequest()
-                            && request.getMethod() == Method.TRACE) {
-                        onTraceRequest(handlerRequest, handlerResponse);
-                    } else if (!checkMaxPostSize(request.getContentLength())) {
-                        handlerResponse.getResponse().getProcessingState().setError(true);
-                        HtmlHelper.setErrorAndSendErrorPage(
-                                handlerRequest, handlerResponse,
-                                config.getDefaultErrorPageGenerator(),
-                                400, HttpStatus.BAD_REQUEST_400.getReasonPhrase(),
-                                "The request payload size exceeds the max post size limitation", null);
-                    } else {
-                        if (guard.mayHandle(handlerRequest)) {
-                            final HttpHandler httpHandlerLocal = httpHandler;
-                            if (httpHandlerLocal != null) {
-                                wasSuspended = !httpHandlerLocal.doHandle(
-                                    handlerRequest, handlerResponse);
-                            }
-                        } else {
-                            handlerResponse.getResponse().getProcessingState().setError(true);
-                            HtmlHelper.setErrorAndSendErrorPage(
-                                    handlerRequest, handlerResponse,
-                                    config.getDefaultErrorPageGenerator(),
-                                    503, "Service Temporary Unavailable",
-                                    "The server is temporary overloaded...", null);
-                        }
-                    }
-                } catch (Exception t) {
-                    LOGGER.log(Level.WARNING,
-                            LogMessages.WARNING_GRIZZLY_HTTP_SERVER_FILTER_HTTPHANDLER_INVOCATION_ERROR(), t);
-
-                    request.getProcessingState().setError(true);
-
-                    if (!response.isCommitted()) {
-                            HtmlHelper.setErrorAndSendErrorPage(
-                                    handlerRequest, handlerResponse,
-                                    config.getDefaultErrorPageGenerator(),
-                                    500, HttpStatus.INTERNAL_SERVER_ERROR_500.getReasonPhrase(),
-                                    HttpStatus.INTERNAL_SERVER_ERROR_500.getReasonPhrase(),
-                                    t);
-                    }
-                } catch (Throwable t) {
-                    ExceptionUtils.handleThrowable(t);
-                    LOGGER.log(Level.WARNING,
-                            LogMessages.WARNING_GRIZZLY_HTTP_SERVER_FILTER_UNEXPECTED(), t);
-                    throw new IllegalStateException(t);
-                }
-
-                if (!wasSuspended) {
-                    return afterService(ctx, connection,
-                            handlerRequest, handlerResponse);
-                } else {
-                    return ctx.getSuspendAction();
-                }
-            } else {
-                // We're working with suspended HTTP request
-                try {
-                    ctx.suspend();
-                    final NextAction action = ctx.getSuspendAction();
-
-                    if (!handlerRequest.getInputBuffer().append(httpContent)) {
-                        // we don't want this thread/context to reset
-                        // OP_READ on Connection
-
-                        // we have enough data? - terminate filter chain execution
-                        ctx.completeAndRecycle();
-                    } else {
-                        ctx.resume(ctx.getStopAction());
-                    }
-
-                    return action;
-                } finally {
-                    httpContent.recycle();
-                }
-            }
-        } else { // this code will be run, when we resume the context
+        if (false == HttpPacket.isHttp(message)) {
+            // this code will be run, when we resume the context
             // We're finishing the request processing
             final Response response = (Response) message;
             final Request request = response.getRequest();
             return afterService(ctx, connection, request, response);
         }
+        
+        // Otherwise cast message to a HttpContent
+        final HttpContent httpContent = (HttpContent) message;
+        final HttpContext context = httpContent.getHttpHeader().getProcessingState().getHttpContext();
+        Request handlerRequest = httpRequestInProgress.get(context);
+
+        if (handlerRequest != null) {
+            // We're working with suspended HTTP request
+            try {
+                ctx.suspend();
+                final NextAction action = ctx.getSuspendAction();
+
+                if (!handlerRequest.getInputBuffer().append(httpContent)) {
+                    // we don't want this thread/context to reset
+                    // OP_READ on Connection
+
+                    // we have enough data? - terminate filter chain execution
+                    ctx.completeAndRecycle();
+                } else {
+                    ctx.resume(ctx.getStopAction());
+                }
+
+                return action;
+            } finally {
+                httpContent.recycle();
+            }
+        }
+        // It's a new HTTP request
+        final HttpRequestPacket request = (HttpRequestPacket) httpContent.getHttpHeader();
+        final HttpResponsePacket response = request.getResponse();
+        ServerFilterConfiguration config = getConfiguration();
+
+        handlerRequest = OXRequest.create(grizzlyConfig);
+        handlerRequest.parameters.setLimit(config.getMaxRequestParameters());
+        httpRequestInProgress.set(context, handlerRequest);
+        final Response handlerResponse = handlerRequest.getResponse();
+
+        handlerRequest.initialize(request, ctx, this);
+        handlerResponse.initialize(handlerRequest, response,
+                ctx, suspendedResponseQueue, this);
+
+        if (config.isGracefulShutdownSupported()) {
+            activeRequestsCounter.incrementAndGet();
+            handlerRequest.addAfterServiceListener(flushResponseHandler);
+        }
+
+        HttpServerProbeNotifier.notifyRequestReceive(this, connection,
+                handlerRequest);
+
+        boolean wasSuspended = false;
+
+        try {
+            ctx.setMessage(handlerResponse);
+
+            if (shuttingDown.get()) { // if we're in the shutting down phase - serve shutdown page and exit
+                handlerResponse.getResponse().getProcessingState().setError(true);
+                HtmlHelper.setErrorAndSendErrorPage(
+                        handlerRequest, handlerResponse,
+                        config.getDefaultErrorPageGenerator(),
+                        503, HttpStatus.SERVICE_UNAVAILABLE_503.getReasonPhrase(),
+                        "The server is being shutting down...", null);
+            } else if (!config.isPassTraceRequest()
+                    && request.getMethod() == Method.TRACE) {
+                onTraceRequest(handlerRequest, handlerResponse);
+            } else if (!checkMaxPostSize(request.getContentLength())) {
+                handlerResponse.getResponse().getProcessingState().setError(true);
+                HtmlHelper.setErrorAndSendErrorPage(
+                        handlerRequest, handlerResponse,
+                        config.getDefaultErrorPageGenerator(),
+                        400, HttpStatus.BAD_REQUEST_400.getReasonPhrase(),
+                        "The request payload size exceeds the max post size limitation", null);
+            } else {
+                if (guard.mayHandle(handlerRequest)) {
+                    final HttpHandler httpHandlerLocal = httpHandler;
+                    if (httpHandlerLocal != null) {
+                        wasSuspended = !httpHandlerLocal.doHandle(
+                            handlerRequest, handlerResponse);
+                    }
+                } else {
+                    handlerResponse.getResponse().getProcessingState().setError(true);
+                    HtmlHelper.setErrorAndSendErrorPage(
+                            handlerRequest, handlerResponse,
+                            config.getDefaultErrorPageGenerator(),
+                            503, "Service Temporary Unavailable",
+                            "The server is temporary overloaded...", null);
+                }
+            }
+        } catch (Exception t) {
+            LOGGER.log(Level.WARNING,
+                    LogMessages.WARNING_GRIZZLY_HTTP_SERVER_FILTER_HTTPHANDLER_INVOCATION_ERROR(), t);
+
+            request.getProcessingState().setError(true);
+
+            if (!response.isCommitted()) {
+                    HtmlHelper.setErrorAndSendErrorPage(
+                            handlerRequest, handlerResponse,
+                            config.getDefaultErrorPageGenerator(),
+                            500, HttpStatus.INTERNAL_SERVER_ERROR_500.getReasonPhrase(),
+                            HttpStatus.INTERNAL_SERVER_ERROR_500.getReasonPhrase(),
+                            t);
+            }
+        } catch (Throwable t) {
+            ExceptionUtils.handleThrowable(t);
+            LOGGER.log(Level.WARNING,
+                    LogMessages.WARNING_GRIZZLY_HTTP_SERVER_FILTER_UNEXPECTED(), t);
+            throw new IllegalStateException(t);
+        }
+
+        if (!wasSuspended) {
+            return afterService(ctx, connection, handlerRequest, handlerResponse);
+        }
+        return ctx.getSuspendAction();
     }
 
     /**
@@ -352,10 +319,9 @@ public class OXHttpServerFilter extends HttpServerFilter {
 
     private NextAction afterService(
             final FilterChainContext ctx,
-            final Connection connection,
+            final Connection<?> connection,
             final Request request,
-            final Response response)
-            throws IOException {
+            final Response response) {
 
         final HttpContext context = request.getRequest()
                 .getProcessingState().getHttpContext();
@@ -423,6 +389,7 @@ public class OXHttpServerFilter extends HttpServerFilter {
      * The {@link CompletionHandler} to be used to make sure the response data
      * have been flushed.
      */
+    @SuppressWarnings("synthetic-access")
     private final class FlushResponseHandler extends EmptyCompletionHandler<Object> implements AfterServiceListener{
 
         private final FilterChainEvent event = TransportFilter.createFlushEvent(this);
@@ -430,7 +397,7 @@ public class OXHttpServerFilter extends HttpServerFilter {
         FlushResponseHandler() {
             super();
         }
-
+        
         @Override
         public void cancelled() {
             onRequestCompleteAndResponseFlushed();
