@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -51,8 +23,8 @@ package com.openexchange.http.requestwatcher.osgi.services;
 
 import java.util.Collections;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicInteger;
 import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 
 /**
  * {@link HttpServletRequestRegistryEntry} keeps track of the incoming Request and its associated thread. The Date of instantiation is saved
@@ -66,9 +38,9 @@ public class RequestRegistryEntry implements Comparable<RequestRegistryEntry> {
     private final Thread thread;
     private final Map<String, String> propertyMap;
     private final HttpServletRequest request;
-    private final HttpServletResponse response;
     private final long birthTime;
     private final int hash;
+    private final AtomicInteger exceededCounter;
 
     /**
      * Initializes a new {@link RequestRegistryEntry}.
@@ -78,14 +50,14 @@ public class RequestRegistryEntry implements Comparable<RequestRegistryEntry> {
      * @param thread the thread associated with the request
      * @param propertyMap
      */
-    public RequestRegistryEntry(long number, HttpServletRequest request, HttpServletResponse response, Thread thread,  Map<String, String> propertyMap) {
+    public RequestRegistryEntry(long number, HttpServletRequest request, Thread thread, Map<String, String> propertyMap) {
         super();
         this.number = number;
         this.thread = thread;
         this.propertyMap = null == propertyMap ? Collections.<String, String> emptyMap() : propertyMap;
         this.request = request;
-        this.response = response;
         this.birthTime = System.currentTimeMillis();
+        this.exceededCounter = new AtomicInteger(1);
 
         final int prime = 31;
         int result = 1;
@@ -93,6 +65,15 @@ public class RequestRegistryEntry implements Comparable<RequestRegistryEntry> {
         hash = result;
     }
 
+    /**
+     * Gets the current exceeded counter and increments it.
+     *
+     * @return The current exceeded counter
+     */
+    public int getAndIncrementExceededCounter() {
+        return exceededCounter.getAndIncrement();
+    }
+
     /**
      * Get the age of this entry.
      *
@@ -118,7 +99,7 @@ public class RequestRegistryEntry implements Comparable<RequestRegistryEntry> {
      */
     public String getRequestParameters() {
         final StringBuilder sa = new StringBuilder();
-        @SuppressWarnings("unchecked") final Map<String, String[]> parameterMap = request.getParameterMap();
+        final Map<String, String[]> parameterMap = request.getParameterMap();
         final String[] parameterNames = parameterMap.keySet().toArray(new String[0]);
         for (int i = 0; i < parameterNames.length; i++) {
             final String[] parameterValues = parameterMap.get(parameterNames[i]);
